@@ -20,7 +20,7 @@ class Modrinth(Writer):
             "path": relative_path.as_posix(),
             "hashes": {"sha1": resource.file.hash.sha1, "sha512": resource.file.hash.sha512},
             "downloads": sorted(provider.url for provider in resource.providers.values()),
-            "fileSize": resource.file.path.stat().st_size
+            "fileSize": resource.file.size
         }
 
         if resource.optional: data['env'] = {"client": "optional", "server": "optional"}
