@@ -9,7 +9,7 @@ from urllib.parse import urlparse
 import keyring as secret_store
 from argparse import SUPPRESS, ArgumentParser, Namespace
 from aiohttp_client_cache.session import CachedSession
-from pytoml import loads as parse_toml
+from tomli import loads as parse_toml
 
 from .. import config
 from .structures import Intermediate, Resource
@@ -87,7 +87,7 @@ def parse_args() -> Namespace:
 
     formats = ('packwiz', 'Modrinth', 'CurseForge', 'Intermediate')
     mr_search = ('exact', 'accurate', 'loose')
-    providers = ('GitHub', 'CurseForge', 'Modrinth')
+    providers = ('GitHub', 'CurseForge', 'Modrinth', 'Other')
  
     arg_parser = ArgumentParser(usage=SUPPRESS, add_help=False)
     arg_parser.add_argument('-h', '--help', dest="help", action='store_true')
@@ -97,6 +97,7 @@ def parse_args() -> Namespace:
     arg_parser.add_argument('-o', '--output', dest='output', type=Path, default=Path.cwd())
     arg_parser.add_argument('--modrinth-search', dest='modrinth_search', type=str, choices=mr_search, default='exact')
     arg_parser.add_argument('--exclude-providers', dest='excluded_providers', type=str, nargs="+", choices=providers, default=[])
+    arg_parser.add_argument('--provider-priority', dest="providers_priority", type=str, nargs="+", choices=providers)
     arg_parser.add_argument('--skip-cache', dest='skip_cache', action='store_true')
     arg_parser.add_argument('-v', '--version', dest='modpack_version', type=str)
     arg_parser.add_argument('--scheme', dest='scheme', type=str)
@@ -127,6 +128,17 @@ def parse_args() -> Namespace:
             print("Default will be used for this run.")
             config.output_naming_scheme = old_scheme
 
+    if priority := args.providers_priority:
+
+        if "GitHub" in priority: 
+            gh_id = priority.index("GitHub"); priority.pop(gh_id)
+            if "Other" not in priority: priority.insert(gh_id, "Other")
+
+        if len(set(priority)) < len(config.providers_priority):
+            print("You must specify ALL providers in providers priority!")
+            print("Default priority will be used for this run.")
+        else: config.providers_priority = tuple(priority)
+
     if args.cmd and args.cmd == "purge-cache":
         if not args.cache_web \
             or not args.cache_files \
@@ -175,7 +187,9 @@ def read_config_into(cfg_path: Path, intermediate: Intermediate) -> None:
                 elif urlparse(url).netloc not in allowed_domains:
                     print(f"Failed to read config for {resource.name}, wrong url domain!")
                     print(f"Allowed domains: {pformat(allowed_domains)}")
-                else: resource.providers['Other'] = Resource.Provider(url = url)
+                else: 
+                    resource.providers.clear()
+                    resource.providers['Other'] = Resource.Provider(url = url)
 
             case "remove": 
                 intermediate.resources.remove(resource)
